ResourceControlPolicyOverrides

Struct ResourceControlPolicyOverrides 

pub struct ResourceControlPolicyOverrides {
Show 33 fields pub wasm_fuel_unit: Option<Amount>, pub evm_fuel_unit: Option<Amount>, pub read_operation: Option<Amount>, pub write_operation: Option<Amount>, pub byte_runtime: Option<Amount>, pub byte_read: Option<Amount>, pub byte_written: Option<Amount>, pub blob_read: Option<Amount>, pub blob_published: Option<Amount>, pub blob_byte_read: Option<Amount>, pub blob_byte_published: Option<Amount>, pub operation: Option<Amount>, pub operation_byte: Option<Amount>, pub message: Option<Amount>, pub message_byte: Option<Amount>, pub service_as_oracle_query: Option<Amount>, pub http_request: Option<Amount>, pub maximum_wasm_fuel_per_block: Option<u64>, pub maximum_evm_fuel_per_block: Option<u64>, pub maximum_service_oracle_execution_ms: Option<u64>, pub maximum_block_size: Option<u64>, pub maximum_blob_size: Option<u64>, pub maximum_published_blobs: Option<u64>, pub maximum_bytecode_size: Option<u64>, pub maximum_block_proposal_size: Option<u64>, pub maximum_bytes_read_per_block: Option<u64>, pub maximum_bytes_written_per_block: Option<u64>, pub maximum_oracle_response_bytes: Option<u64>, pub maximum_http_response_bytes: Option<u64>, pub http_request_timeout_ms: Option<u64>, pub http_request_allow_list: Option<Vec<String>>, pub free_application_ids: Option<Vec<String>>, pub flags: Option<Vec<String>>,
}
Optional overrides for fields in the active resource control policy.

Fields

wasm_fuel_unit: Option<Amount>

Set the price per unit of Wasm fuel.

evm_fuel_unit: Option<Amount>

Set the price per unit of EVM fuel.

read_operation: Option<Amount>

Set the price per read operation.

write_operation: Option<Amount>

Set the price per write operation.

byte_runtime: Option<Amount>

Set the price per byte read from runtime.

byte_read: Option<Amount>

Set the price per byte read.

byte_written: Option<Amount>

Set the price per byte written.

blob_read: Option<Amount>

Set the base price to read a blob.

blob_published: Option<Amount>

Set the base price to publish a blob.

blob_byte_read: Option<Amount>

Set the price to read a blob, per byte.

blob_byte_published: Option<Amount>

The price to publish a blob, per byte.

operation: Option<Amount>

Set the base price of sending an operation from a block..

operation_byte: Option<Amount>

Set the additional price for each byte in the argument of a user operation.

message: Option<Amount>

Set the base price of sending a message from a block..

message_byte: Option<Amount>

Set the additional price for each byte in the argument of a user message.

service_as_oracle_query: Option<Amount>

Set the price per query to a service as an oracle.

http_request: Option<Amount>

Set the price for performing an HTTP request.

maximum_wasm_fuel_per_block: Option<u64>

Set the maximum amount of Wasm fuel per block.

maximum_evm_fuel_per_block: Option<u64>

Set the maximum amount of EVM fuel per block.

maximum_service_oracle_execution_ms: Option<u64>

Set the maximum time in milliseconds that a block can spend executing services as oracles.

maximum_block_size: Option<u64>

Set the maximum size of a block, in bytes.

maximum_blob_size: Option<u64>

Set the maximum size of data blobs, compressed bytecode and other binary blobs, in bytes.

maximum_published_blobs: Option<u64>

Set the maximum number of published blobs per block.

maximum_bytecode_size: Option<u64>

Set the maximum size of decompressed contract or service bytecode, in bytes.

maximum_block_proposal_size: Option<u64>

Set the maximum size of a block proposal, in bytes.

maximum_bytes_read_per_block: Option<u64>

Set the maximum read data per block.

maximum_bytes_written_per_block: Option<u64>

Set the maximum write data per block.

maximum_oracle_response_bytes: Option<u64>

Set the maximum size of oracle responses.

maximum_http_response_bytes: Option<u64>

Set the maximum size in bytes of a received HTTP response.

http_request_timeout_ms: Option<u64>

Set the maximum amount of time allowed to wait for an HTTP response.

http_request_allow_list: Option<Vec<String>>

Set the list of hosts that contracts and services can send HTTP requests to.

free_application_ids: Option<Vec<String>>

Set the list of application IDs for which message- and event-related fees are waived.

flags: Option<Vec<String>>

Set the protocol flags that are enabled.